@@ -57,7 +57,7 @@ matchMatrixLinesToRef <- function(mat, ref, exclCol=NULL, addRef=TRUE, inclInfo=
       if(length(ref) != length(newOr)) addRef <- FALSE
       out <- if(length(newOr) ==1 || ncol(mat)==1) matrix(mat[newOr,], nrow=length(newOr), dimnames=list(rownames(mat)[newOr], colnames(mat))) else mat[newOr,]
       if(length(matElim) >0) {
-        cat("aOO1 \n"); aOO1 <- list(out=out,mat=mat,ref=ref,newOr=newOr,goodCol=goodCol,matElim=matElim,chIdenCol=chIdenCol,addRef=addRef)
+        if(debug) {message(fxNa, "mMLR1"); mMLR1 <- list(out=out,mat=mat,ref=ref,newOr=newOr,goodCol=goodCol,matElim=matElim,chIdenCol=chIdenCol,addRef=addRef)}
         outDiNa <- list(rownames(mat), colnames(out)[-1*which(colnames(out) %in% colnames(matElim))])
         rmCol <- which(colnames(out) %in% colnames(matElim))
         out <- if(length(rmCol) < ncol(out) -1) out[,-1*rmCol] else matrix( out[,-1*rmCol], nrow=nrow(mat), dimnames=list(outDiNa[[1]], outDiNa[[1]][-1*rmCol]))
@@ -90,7 +90,7 @@ matchMatrixLinesToRef <- function(mat, ref, exclCol=NULL, addRef=TRUE, inclInfo=
         matUse <- if(sum(!chIdenCol) ==1) matrix(mat[,which(!chIdenCol)], ncol=1, dimnames=list(rownames(mat), colnames(mat)[which(!chIdenCol)])) else mat[,which(!chIdenCol)]
         if(debug) message(fxNa,"Removing ",sum(chIdenCol), "columns of all identical values (have no value for distinguishing lines)")
       } else matUse <- mat
-      if(debug) {message(fxNa,"mML1"); mML1 <- list(mat=mat,matUse=matUse,ref=ref,matElim=matElim,chIdenCol=chIdenCol,out=out )}
+      if(debug) {message(fxNa,"mMLR2"); mMLR2 <- list(mat=mat,matUse=matUse,ref=ref,matElim=matElim,chIdenCol=chIdenCol,out=out )}
       ## exclude specified column(s) : exclCol
       if(length(exclCol) >0) {
         exclCol <- if(is.character(exclCol)) naOmit(colnames(matUse) %in% exclCol) else as.integer(naOmit(exclCol[which(exclCol >0 & exclCol <= ncol(mat))] ))
@@ -112,22 +112,22 @@ matchMatrixLinesToRef <- function(mat, ref, exclCol=NULL, addRef=TRUE, inclInfo=
           byCol <- which(chNa==0)[1]
           msgM <- "direct match"
         } else {
-          if(debug) {message(fxNa,"mML2"); mML2 <- list()}
+          if(debug) {message(fxNa,"mMLR3"); mMLR13 <- list()}
           ## trim redundant text, re-try match
           mat2 <- apply(if(length(matUse) >0) matUse else mat, 2, trimRedundText, minNchar=1, side="both", silent=silent,callFrom=fxNa,debug=debug)
           ref2 <- trimRedundText(ref, minNchar=1, side="both", silent=silent,callFrom=fxNa,debug=debug)
           sMa <- apply(mat2, 2, function(x) match(ref2, x))
           chNa <- colSums(is.na(sMa))
-          if(debug) {message(fxNa,"mML2b"); mML2b <- list()}
+          if(debug) {message(fxNa,"mMLR3b"); mMLR3b <- list()}
           if(any(chNa==0)) { newOr <- sMa[,which(chNa==0)[1]]
             out <- .applyOrder(mat=mat, ref=ref, newOr=newOr, addRef=addRef)  #
             #old#out <- .applyOrder(mat=mat, ref=ref, newOr=newOr, goodCol=chNa, matElim=matElim, chIdenCol=chIdenCol, addRef=addRef)  #
             byCol <- which(chNa==0)[1]
             msgM <- "direct match after trimming redundant text"
-            if(debug) {message(fxNa,"mML2c"); mML2c <- list()}
+            if(debug) {message(fxNa,"mMLR3c"); mMLR3c <- list()}
           } else {
             ## direct matching not successful, check if grep possible (only when pattern not longer than x)
-            if(debug) {message(fxNa,"mML3"); mML3 <- list(mat=mat,ref=ref,matElim=matElim,chIdenCol=chIdenCol,out=out,chNa=chNa,mat2=mat2,ref2=ref2,sMa=sMa )}
+            if(debug) {message(fxNa,"mMLR4"); mMLR4 <- list(mat=mat,ref=ref,matElim=matElim,chIdenCol=chIdenCol,out=out,chNa=chNa,mat2=mat2,ref2=ref2,sMa=sMa )}
             leM <- nchar(as.matrix(mat2))
             leR <- nchar(ref2)
             refPoss <- apply(leM, 2, function(x) all(sort(x, decreasing=TRUE)[1:length(leR)] >= sort(leR, decreasing=TRUE)))
@@ -146,20 +146,20 @@ matchMatrixLinesToRef <- function(mat, ref, exclCol=NULL, addRef=TRUE, inclInfo=
               ## check by harmonizing/trimming enumerators
               mat3 <- apply(mat2, 2, rmEnumeratorName, nameEnum=c("Number","No","#","Replicate","Sample","Speciem"), sepEnum=c(" ","-","_"), newSep="_No", incl=c("anyCase","trim1"), silent=debug, debug=debug, callFrom=fxNa)
               chCol <- colSums(mat2 ==mat3) < nrow(mat2)      # see if change in all elements in a given column
-              if(debug) {message(fxNa,"mML4"); mML4 <- list() }
+              if(debug) {message(fxNa,"mMLR5"); mMLR5 <- list() }
               if(any(chCol)) {
                 if(debug) message(fxNa,"Enumerators exist, try matching after harmonizing style ..")
                 if(!all(chCol)) mat3 <- if(sum(chCol) >1) mat3[,which(chCol)] else matrix(mat3[,which(chCol)], nrow=nrow(mat), dimnames=list(rownames(mat2), colnames(mat2)[which(chCol)]))  # trim
                 ref3 <- rmEnumeratorName(ref, nameEnum=c("","Number","No","#","Replicate","Sample","Speciem"), sepEnum=c(" ","-","_"), newSep="_No", incl=c("anyCase","trim1"), silent=debug, debug=debug, callFrom=fxNa)
                 chDir <- apply(mat3, 2, match, ref3)
                 chMa <- apply(chDir, 2, function(x) all(1:nrow(mat) %in% x, na.rm=TRUE))
-                if(debug) {message(fxNa,"mML4b"); mML4b <- list() }
+                if(debug) {message(fxNa,"mMLR5b"); mMLR5b <- list() }
                 if(any(chMa)) {
                   goodCol <- which(chMa)[1]
                   if(debug) message(fxNa,"Found good hit by using column '",names(goodCol),"'  ie ",pasteC(utils::head(mat2[,goodCol]))," ...")
                   out <- if(addRef) cbind(mat[chDir[,goodCol],], ref=ref) else mat[chDir[,goodCol],]
                   msgM <- "Match after harmonizing enumerators (& trimming redundant text)"
-                  if(debug) {message(fxNa,"mML4c"); mML4c <- list() }
+                  if(debug) {message(fxNa,"mMLR5c"); mMLR5c <- list() }
                 } else {
                   if(debug) message(fxNa,"Try matching all after trimming enumerators")
                   mat3 <- apply(mat2, 2, rmEnumeratorName, nameEnum=c("Number","No","#","Replicate","Sample","Speciem"), sepEnum=c(" ","-","_"), newSep="", incl=c("anyCase","trim1","rmEnum"), silent=debug, debug=debug, callFrom=fxNa)
@@ -181,7 +181,7 @@ matchMatrixLinesToRef <- function(mat, ref, exclCol=NULL, addRef=TRUE, inclInfo=
                 chRL <- sapply(chRev, sapply, length)       # number of grp hits
                 ch1 <- (if(ncol(mat) >1) colSums(chRL ==1) else sum(chRL==1)) ==length(ref)
                 if(any(ch1)) { newOr <- if(is.list(chRev)) order(unlist(chRev[[which(ch1)[1]]], use.names=FALSE)) else chRev[,which(ch1)[1]]         # new order for mat
-                  if(debug) {message(fxNa,"mML5") }
+                  if(debug) {message(fxNa,"mMLR6") }
                   out <- cbind(if(any(dim(mat)==1, length(newOr)==1)) matrix(mat[newOr,], ncol=ncol(mat), dimnames=list(rownames(mat)[newOr], colnames(mat))) else mat[newOr,],
                     if(any(dim(matElim)==1, length(newOr)==1)) matrix(matElim[newOr,], ncol=ncol(matElim), dimnames=list(rownames(matElim)[newOr], colnames(matElim))) else matElim[newOr,])
                   if(length(matElim) >0) out <- out[,match(names(chIdenCol), colnames(out))]   # adjust init col-order
@@ -194,7 +194,7 @@ matchMatrixLinesToRef <- function(mat, ref, exclCol=NULL, addRef=TRUE, inclInfo=
           }
         }
       }  
-      if(debug) {message(fxNa,"mML6"); mML6 <- list(mat=mat,ref=ref,matElim=matElim,chIdenCol=chIdenCol,out=out )}
+      if(debug) {message(fxNa,"mMLR7"); mMLR7 <- list(mat=mat,ref=ref,matElim=matElim,chIdenCol=chIdenCol,out=out )}
       if(length(msg) >0 && !silent) message(fxNa,msg,"!  Returning NULL")
       if(debug && length(newOr) >0) message(fxNa,"Successfully found new order by ",msgM," : ",pasteC(newOr, quoteC="'"))
     }
