@@ -5,7 +5,8 @@
 #' Multiple testing correction should be performed with caution, short series of p-values typically pose problems for transforming to lfdr. 
 #' The transformation to lfdr values may give warning messages, in this case the resultant lfdr values may be invalid ! 
 #' @param x (numeric) vector of p.values
-#' @param silent (logical) suppres messages
+#' @param silent (logical) suppress messages
+#' @param debug (logical) additional messages for debugging
 #' @param callFrom (character) allow easier tracking of messages produced
 #' @return This function returns a (numeric) vector of lfdr values (or \code{NULL} if data insufficient to run the function 'fdrtool')
 #' @seealso lfdr from \code{\link[fdrtool]{fdrtool}}, other p-adjustments (multiple test correction, eg FDR) in \code{\link[stats]{p.adjust}} 
@@ -18,21 +19,29 @@
 #' t8[5:8,5:6] <- t8[5:8,5:6]+3   # augment lines 5:8 (e-h) for AA2&BB2 (c,d,g,h should be found)
 #' head(pVal2lfdr(apply(t8, 1, function(x) t.test(x[1:4], x[5:8])$p.value)))
 #' @export
-pVal2lfdr <- function(x, silent=TRUE, callFrom=NULL) {    ## take vector of p-values and return vector of lfdr-values
+pVal2lfdr <- function(x, silent=TRUE, debug=FALSE, callFrom=NULL) {    ## take vector of p-values and return vector of lfdr-values
   fxNa <- .composeCallName(callFrom, newNa="pVal2lfdr")
-  if(!isTRUE(silent)) silent <- FALSE
-  if(!requireNamespace("fdrtool", quietly = TRUE)) {
-    warning("package 'fdrtool' not found ! Please install from CRAN  ... (returning NULL)")
-    return(NULL) 
-  } else {
-    if(sum(is.na(x)) >0 & !silent) message(fxNa," omitting ",sum(is.na(x))," NAs !")
-    z <- as.numeric(naOmit(x)) 
-    z <- try(fdrtool::fdrtool(z, statistic="pvalue", plot=FALSE, verbose=!silent)$lfdr, silent=TRUE)
-    if(inherits(z, "try-error")) { message(fxNa," FAILED to calulate lfdr !  Check how to use package 'fdrtool' (data too small ?)")
-      return(NULL) 
-    } else { z <- as.numeric(z)
-      lfdr <- rep(NA, length(x))
-      lfdr[!is.na(x)] <- z                          #  for returning NA at place of initial NAs
-      if(!is.null(names(x))) names(lfdr) <- names(x)
-      lfdr }}}
+  if(isTRUE(debug)) silent <- FALSE else { debug <- FALSE
+    if(!isTRUE(silent)) silent <- FALSE }
+
+  if(length(x) >0) {
+    chNa <- is.na(x)
+    if(any(chNa)) { if(!silent) message(fxNa,"Omitting ",sum(chNa)," NAs !")
+      z <- try(as.numeric(naOmit(x)), silent=TRUE) 
+    } else z <- x
+    rm(chNa)
+    if(inherits(z, "try-error")) stop(fxNa,"FAILED to convert 'x' into numeric data !") else {
+      if(requireNamespace("fdrtool", quietly=TRUE)) {
+        z <- try(fdrtool::fdrtool(z, statistic="pvalue", plot=FALSE, verbose=!silent)$lfdr, silent=TRUE)
+        if(inherits(z, "try-error")) { message(fxNa,"FAILED to calulate lfdr !  Check how to use package 'fdrtool' (data too small ?)")
+          return(NULL) 
+        } else { z <- as.numeric(z)
+          lfdr <- rep(NA, length(x))
+          lfdr[!is.na(x)] <- z                          #  for returning NA at place of initial NAs
+          if(!is.null(names(x))) names(lfdr) <- names(x)
+          lfdr }
+      } else message(fxNa,"NOTE: package 'fdrtool' not found ! Please install first from CRAN  ... (returning NULL)")
+    }
+  }
+}
       
